
# SISCone is a Seedless Infrared Safe Cone jet algorithm.

This algorithm for identifying jets in high-energy particle collisions
was developed by Gavin Salam and Gregory Soyez and implements the
approach described in [arXiv:0704.0292](https://arxiv.org/abs/) ([JHEP
05 (2007) 086](https://doi.org/10.1088/1126-6708/2007/05/086))

Most users should get it as packaged with [FastJet](https://fastjet.fr),
where it is available as a plugin. However it can also be used in
standalone form from this repository. For installation instructions, see
the [INSTALL.md](INSTALL.md) file.

Further documentation is available on the main SISCone [web
page](https://siscone.hepforge.org/) (also available in doc/html) and
the developer's doxygen documentation in doc/devel/html (you may need to
run doxygen for the latter to be present).

